Index: /trunk/psLib/test/collections/tst_psBitSet_02.c
===================================================================
--- /trunk/psLib/test/collections/tst_psBitSet_02.c	(revision 1178)
+++ /trunk/psLib/test/collections/tst_psBitSet_02.c	(revision 1179)
@@ -6,10 +6,11 @@
  *     A)  Create two psBitSets
  *     B)  Perform binary AND with psBitSets
- *     C)  Free psBitSets
+ *     C)  Perform binary AND and auto allocate output
+ *     D)  Free psBitSets
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.6 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-07-01 21:56:15 $
+ *  @version $Revision: 1.7 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-07-01 23:09:53 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -24,4 +25,5 @@
 {
     char *binOut = NULL;
+    char *binOut2 = NULL;
 
 
@@ -49,5 +51,4 @@
     printFooter(stdout, "psBitSet", "Create two psBitSets", true);
 
-
     // Test B - Perform binary AND with psBitSets
     printPositiveTestHeader(stdout,"psBitSet", "Perform binary AND with psBitSets");
@@ -61,9 +62,21 @@
 
 
-    // Test C - Free psBitSets
+    // Test C - Perform binary AND and auto allocate output
+    printPositiveTestHeader(stdout,"psBitSet", "Perform binary AND and auto allocate output");
+    psBitSet* outbs2 = NULL;
+    outbs2 = psBitSetOp(outbs2, bs1, "AND", bs2);
+    binOut2 = psBitSetToString(outbs2);
+    printf("Result:\n");
+    printf("%s\n", binOut2);
+    psFree(binOut2);
+    printFooter(stdout, "psBitSet", "Perform binary AND and auto allocate output", true);
+
+
+    // Test D - Free psBitSets
     printPositiveTestHeader(stdout, "psBitSet", "Free psBitSets");
     psFree(bs1);
     psFree(bs2);
     psFree(outbs);
+    psFree(outbs2);
     psMemCheckLeaks(0, NULL, stdout);
     int nBad = psMemCheckCorruption(0);
